==> openshift-model-6.7.1-sources.jar: io/fabric8/openshift/api/model/ClusterResourceQuotaBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ClusterResourceQuotaBuilder extends ClusterResourceQuotaFluentImpl<ClusterResourceQuotaBuilder> implements VisitableBuilder<ClusterResourceQuota,ClusterResourceQuotaBuilder>{
  public ClusterResourceQuotaBuilder() {
    this(false);
  }
  public ClusterResourceQuotaBuilder(Boolean validationEnabled) {
    this(new ClusterResourceQuota(), validationEnabled);
  }
  public ClusterResourceQuotaBuilder(ClusterResourceQuotaFluent<?> fluent) {
    this(fluent, false);
  }
  public ClusterResourceQuotaBuilder(ClusterResourceQuotaFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ClusterResourceQuota(), validationEnabled);
  }
  public ClusterResourceQuotaBuilder(ClusterResourceQuotaFluent<?> fluent,ClusterResourceQuota instance) {
    this(fluent, instance, false);
  }
  public ClusterResourceQuotaBuilder(ClusterResourceQuotaFluent<?> fluent,ClusterResourceQuota instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withSpec(instance.getSpec());
      fluent.withStatus(instance.getStatus());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ClusterResourceQuotaBuilder(ClusterResourceQuota instance) {
    this(instance,false);
  }
  public ClusterResourceQuotaBuilder(ClusterResourceQuota instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  ClusterResourceQuotaFluent<?> fluent;
  Boolean validationEnabled;
  public ClusterResourceQuota build() {
    ClusterResourceQuota buildable = new ClusterResourceQuota(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-6.8.1-sources.jar: io/fabric8/openshift/api/model/ClusterResourceQuotaBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ClusterResourceQuotaBuilder extends ClusterResourceQuotaFluent<ClusterResourceQuotaBuilder> implements VisitableBuilder<ClusterResourceQuota,ClusterResourceQuotaBuilder>{
  public ClusterResourceQuotaBuilder() {
    this(false);
  }
  public ClusterResourceQuotaBuilder(Boolean validationEnabled) {
    this(new ClusterResourceQuota(), validationEnabled);
  }
  public ClusterResourceQuotaBuilder(ClusterResourceQuotaFluent<?> fluent) {
    this(fluent, false);
  }
  public ClusterResourceQuotaBuilder(ClusterResourceQuotaFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ClusterResourceQuota(), validationEnabled);
  }
  public ClusterResourceQuotaBuilder(ClusterResourceQuotaFluent<?> fluent,ClusterResourceQuota instance) {
    this(fluent, instance, false);
  }
  public ClusterResourceQuotaBuilder(ClusterResourceQuotaFluent<?> fluent,ClusterResourceQuota instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new ClusterResourceQuota());

    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withSpec(instance.getSpec());
      fluent.withStatus(instance.getStatus());
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withSpec(instance.getSpec());
      fluent.withStatus(instance.getStatus());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ClusterResourceQuotaBuilder(ClusterResourceQuota instance) {
    this(instance,false);
  }
  public ClusterResourceQuotaBuilder(ClusterResourceQuota instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new ClusterResourceQuota());

    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  ClusterResourceQuotaFluent<?> fluent;
  Boolean validationEnabled;
  public ClusterResourceQuota build() {
    ClusterResourceQuota buildable = new ClusterResourceQuota(fluent.getApiVersion(),fluent.getKind(),fluent.buildMetadata(),fluent.buildSpec(),fluent.buildStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
